==> lazy_widget-0.0.2.tar.gz: example/lib/three_stooges.dart <==
import 'package:flutter/material.dart';

class ThreeStoogesPage extends StatefulWidget {
  ThreeStoogesPage({Key key}) : super(key: key);

  @override
  _ThreeStoogesPageState createState() {
    return _ThreeStoogesPageState();
  }
}

class _ThreeStoogesPageState extends State<ThreeStoogesPage>
    with SingleTickerProviderStateMixin {
  final List<String> tabTitles = ["搜索", "订单", "方法", "广告"];
  TabController _tabController;

  @override
  void initState() {
    super.initState();
    _tabController =
        TabController(length: tabTitles.length, vsync: this, initialIndex: 0);
//        TabController(length: tabTitles.length, initialIndex: 0);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(84),
        child: AppBar(
          title: Text(
            "data",
            style: TextStyle(),
          ),
          centerTitle: true,
          bottom: PreferredSize(
            preferredSize: Size.fromHeight(39.0),
            child: Container(
              height: 39,
              child: TabBar(
                controller: _tabController,
                tabs: tabTitles.map((title) {
                  return Text(title);
                }).toList(),
              ),
            ),
          ),
        ),
      ),
      body: TabBarView(
        controller: _tabController,
        children: tabTitles.map((title) {
          return Text(title);
        }).toList(),
      ),
    );
  }
}

==> lazy_widget-1.0.0.tar.gz: example/lib/three_stooges.dart <==
import 'package:flutter/material.dart';

class ThreeStoogesPage extends StatefulWidget {
  ThreeStoogesPage({Key? key}) : super(key: key);

  @override
  _ThreeStoogesPageState createState() {
    return _ThreeStoogesPageState();
  }
}

class _ThreeStoogesPageState extends State<ThreeStoogesPage>
    with SingleTickerProviderStateMixin {
  final List<String> tabTitles = ["搜索", "订单", "方法", "广告"];
  TabController? _tabController;

  @override
  void initState() {
    super.initState();
    _tabController =
        TabController(length: tabTitles.length, vsync: this, initialIndex: 0);
//        TabController(length: tabTitles.length, initialIndex: 0);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(84),
        child: AppBar(
          title: Text(
            "data",
            style: TextStyle(),
          ),
          centerTitle: true,
          bottom: PreferredSize(
            preferredSize: Size.fromHeight(39.0),
            child: Container(
              height: 39,
              child: TabBar(
                controller: _tabController,
                tabs: tabTitles.map((title) {
                  return Text(title);
                }).toList(),
              ),
            ),
          ),
        ),
      ),
      body: TabBarView(
        controller: _tabController,
        children: tabTitles.map((title) {
          return Text(title);
        }).toList(),
      ),
    );
  }
}
